summaryrefslogtreecommitdiff
path: root/src/gui/viewport.h
diff options
context:
space:
mode:
authorBjørn Lindeijer <bjorn@lindeijer.nl>2007-03-21 21:56:12 +0000
committerBjørn Lindeijer <bjorn@lindeijer.nl>2007-03-21 21:56:12 +0000
commit823aa330987205b251d9f662cfdd4c39149c6ec7 (patch)
tree55e78b4621bfc867b5ff1ecee101d46a6d7169e2 /src/gui/viewport.h
parent9d51b2e1077042ae42d42a0e6314e439c62e2925 (diff)
downloadmana-client-823aa330987205b251d9f662cfdd4c39149c6ec7.tar.gz
mana-client-823aa330987205b251d9f662cfdd4c39149c6ec7.tar.bz2
mana-client-823aa330987205b251d9f662cfdd4c39149c6ec7.tar.xz
mana-client-823aa330987205b251d9f662cfdd4c39149c6ec7.zip
Renamed Spriteset to ImageSet.
Diffstat (limited to 'src/gui/viewport.h')
-rw-r--r--src/gui/viewport.h16
1 files changed, 10 insertions, 6 deletions
diff --git a/src/gui/viewport.h b/src/gui/viewport.h
index 6bb82d7f..84efeff3 100644
--- a/src/gui/viewport.h
+++ b/src/gui/viewport.h
@@ -33,6 +33,7 @@
class Map;
class Being;
class FloorItem;
+class ImageSet;
class Item;
class PopupMenu;
class Graphics;
@@ -139,13 +140,13 @@ class Viewport : public WindowContainer, public gcn::MouseListener,
* TODO Find some way to get rid of Being here
*/
void showPopup(int x, int y, Being *being);
-
+
/**
* Draws range based target cursor
*/
void
drawTargetCursor(Graphics *graphics);
-
+
/**
* Draws target name
*/
@@ -162,11 +163,14 @@ class Viewport : public WindowContainer, public gcn::MouseListener,
int mCameraX; /**< Current viewpoint in tiles. */
int mCameraY; /**< Current viewpoint in tiles. */
bool mShowDebugPath; /**< Show a path from player to pointer. */
-
- /**
- * Target animated cursor.
- */
+
+ ImageSet *mInRangeImages; /**< Images of in range target cursor. */
+ ImageSet *mOutRangeImages; /**< Images of out of range target cursor.*/
+
+ /** Animated in range target cursor. */
SimpleAnimation *mTargetCursorInRange;
+
+ /** Animated out of range target cursor. */
SimpleAnimation *mTargetCursorOutRange;
bool mPlayerFollowMouse;